@@ -12,11 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#include <cstdlib>
 #include <iostream>
+#include <vector>
 
 #include <signal.h>
 
-#include <oslogin_utils.h>
+#include "include/oslogin_utils.h"
 
 using std::cout;
 using std::endl;
@@ -51,7 +53,7 @@ int main(int argc, char *argv[]) {
     goto fail;
   }
 
-  sig = { 0 };
+  sig = {};
   sig.sa_handler = signal_handler;
   sigemptyset(&sig.sa_mask);
 
@@ -61,9 +63,11 @@ int main(int argc, char *argv[]) {
   }
 
   user_name = argv[1];
-  opts = { 0 };
+  opts = {};
 
-  if (AuthorizeUser(user_name, opts, &user_response)) {
+  // We hardcode "false" here because Cloud Run will only ever call
+  // AuthorizedPrincipalsCommand, never AuthorizedKeysCommand.
+  if (AuthorizeUser(user_name, opts, &user_response, false)) {
     // At this point, we've verified the user can log in. Grab the ssh keys from
     // the user response.
     std::vector<string> ssh_keys = ParseJsonToSshKeys(user_response);
