@@ -186,6 +186,9 @@ size_t OnCurlWrite(void* buf, size_t size, size_t nmemb, void* userp);
 bool HttpGet(const string& url, string* response, long* http_code);
 bool HttpPost(const string& url, const string& data, string* response,
               long* http_code);
+// Based on known MDS status codes returns whether the HTTP request
+// should be retried or not.
+bool ShouldRetry(long http_code);
 
 // Returns whether user_name is a valid OsLogin user name.
 bool ValidateUserName(const string& user_name);
@@ -226,7 +229,7 @@ bool ParseJsonToUsers(const string& json, std::vector<string>* users);
 bool GetGroupByName(string name, struct group* grp, BufferManager* buf, int* errnop);
 
 // Gets group matching GID.
-bool GetGroupByGID(int gid, struct group* grp, BufferManager* buf, int* errnop);
+bool GetGroupByGID(uint32_t gid, struct group* grp, BufferManager* buf, int* errnop);
 
 // Iterates through all users for a group, storing results in a provided string vector.
 bool GetUsersForGroup(string groupname, std::vector<string>* users, int* errnop);
@@ -294,6 +297,11 @@ extern void SysLogErr(const char *fmt, ...);
 
 // AuthoOptions wraps authorization options.
 struct AuthOptions {
+  // admin_policy_required determines if a user is only authorized if admin
+  // policy is available for such a user. i.e. AuthorizeUser() should return
+  // false if adminLogin is not available.
+  bool admin_policy_required;
+
   // security_key determines if the MDS "/users?..." should use
   // the view=securityKey parameter.
   bool security_key;
@@ -308,7 +316,7 @@ struct AuthOptions {
 
 // Perform user authorization logic & create users files and google sudoers, returns true if successful,
 // and false otherwise.
-bool AuthorizeUser(const char *user_name, struct AuthOptions opts, string *user_response);
+bool AuthorizeUser(const char *user_name, struct AuthOptions opts, string *user_response, bool cloud_run=false);
 
 // Given a file_path extracts the file name only. file_path must be a null terminated string.
 const char *FileName(const char *file_path);
