@@ -14,6 +14,7 @@
 
 // Requires libcurl4-openssl-dev, libjson-c5, and libjson-c-dev
 #include <curl/curl.h>
+#include <curl/easy.h>
 #include <errno.h>
 #include <grp.h>
 #include <json.h>
@@ -24,13 +25,14 @@
 #include <unistd.h>
 #include <sys/stat.h>
 
+#include <cstdint>
 #include <cstring>
 #include <cstdarg>
 #include <iostream>
 #include <sstream>
 #include <fstream>
-
-#include <json_object.h>
+#include <string>
+#include <vector>
 
 #if defined(__clang__) || __GNUC__ > 4 || \
     (__GNUC__ == 4 &&                     \
@@ -42,8 +44,8 @@
 #define Regex boost
 #endif
 
-#include <compat.h>
-#include <oslogin_utils.h>
+#include "include/compat.h"
+#include "include/oslogin_utils.h"
 
 using std::string;
 
@@ -204,7 +206,7 @@ json_object* ParseJsonRoot(const string& json) {
     enum json_tokener_error jerr = json_tokener_get_error(tok);
     string error_message = json_tokener_error_desc(jerr);
     SysLogErr("Failed to parse root JSON element: \"%s\", from input \"%s\"",
-              error_message, json);
+              error_message.c_str(), json.c_str());
   }
 
   json_tokener_free(tok);
@@ -583,7 +585,7 @@ bool ParseJsonToGroups(const string& json, std::vector<Group>* result) {
   json_object* groups;
   json_type groupType;
   if (!json_object_object_get_ex(root, "posixGroups", &groups)) {
-    SysLogErr("failed to parse POSIX groups from \"%s\"", json);
+    SysLogErr("failed to parse POSIX groups from \"%s\"", json.c_str());
     goto cleanup;
   }
   groupType = json_object_get_type(groups);
@@ -607,7 +609,10 @@ bool ParseJsonToGroups(const string& json, std::vector<Group>* result) {
     }
 
     Group g;
-    g.gid = json_object_get_int64(gid);
+    // We use json_object_get_int64 because GIDs are unsigned and may use all
+    // 32 bits, but there is no json_object_get_uint32.
+    // Because the GID should never exceed 32 bits, truncation is safe.
+    g.gid = (uint32_t)json_object_get_int64(gid);
 
     // get_int64 will confusingly return 0 if the string can't be converted to
     // an integer. We can't rely on type check as it may be a string in the API.
@@ -1120,7 +1125,7 @@ bool GetGroupByName(string name, struct group* result, BufferManager* buf, int*
   return true;
 }
 
-bool GetGroupByGID(int gid, struct group* result, BufferManager* buf, int* errnop) {
+bool GetGroupByGID(uint32_t gid, struct group* result, BufferManager* buf, int* errnop) {
   std::stringstream url;
   std::vector<Group> groups;
 
@@ -1299,7 +1304,8 @@ static bool ApplyPolicy(const char *user_name, string email, const char *policy,
 
   if (http_code != 200) {
     SysLogErr("Failed to validate that OS Login user %s has %s permission; "
-              "got HTTP response code: %lu", user_name, policy, http_code);
+              "got HTTP response code: %lu; got HTTP response body: %s",
+              user_name, policy, http_code, response);
     return false;
   }
 
@@ -1316,9 +1322,10 @@ static bool FileExists(const char *file_path) {
   return !stat(file_path, &buff);
 }
 
-static bool CreateGoogleUserFile(string users_filename) {
+static bool CreateGoogleUserFile(string users_filedir, string user_name) {
   std::ofstream users_file;
 
+  string users_filename = (users_filedir + user_name);
   users_file.open(users_filename.c_str());
 
   if (!users_file.is_open()) {
@@ -1326,6 +1333,10 @@ static bool CreateGoogleUserFile(string users_filename) {
     return false;
   }
 
+  // This file gets sourced by sshd_config.
+  users_file << "Match User " + user_name + "\n";
+  users_file << "        AuthorizedKeysFile /dev/null\n";
+
   // We are only creating the file so we could just close it here.
   users_file.close();
 
@@ -1352,7 +1363,7 @@ static bool CreateGoogleSudoersFile(string sudoers_filename, const char *user_na
   return true;
 }
 
-bool AuthorizeUser(const char *user_name, struct AuthOptions opts, string *user_response) {
+bool AuthorizeUser(const char *user_name, struct AuthOptions opts, string *user_response, bool cloud_run) {
   bool users_file_exists, sudoers_exists;
   string email, users_filename, sudoers_filename;
 
@@ -1371,8 +1382,16 @@ bool AuthorizeUser(const char *user_name, struct AuthOptions opts, string *user_
     return false;
   }
 
-  users_filename = kUsersDir;
-  users_filename.append(user_name);
+  // Only check adminLogin for cloud run. Skip file creations.
+  if (cloud_run) {
+    bool result = ApplyPolicy(user_name, email, "adminLogin", opts);
+    if (!result) {
+      SysLogErr("Could not grant root access to organization user: %s.", user_name);
+    }
+    return result;
+  }
+
+  users_filename = string(kUsersDir) + user_name;
   users_file_exists = FileExists(users_filename.c_str());
 
   if (!ApplyPolicy(user_name, email, "login", opts)) {
@@ -1384,14 +1403,13 @@ bool AuthorizeUser(const char *user_name, struct AuthOptions opts, string *user_
     return false;
   }
 
-  if (!users_file_exists && !CreateGoogleUserFile(users_filename)) {
+  if (!users_file_exists && !CreateGoogleUserFile(kUsersDir, user_name)) {
     // If we can't create users file we can't grant access, log it and deny.
     SysLogErr("Failed to create user's file.");
     return false;
   }
 
-  sudoers_filename = kSudoersDir;
-  sudoers_filename.append(user_name);
+  sudoers_filename = string(kSudoersDir) + user_name;
   sudoers_exists = FileExists(sudoers_filename.c_str());
 
   if (ApplyPolicy(user_name, email, "adminLogin", opts)) {
